@extends('crm-admin::main-layout')
@section('breadcrumb')
  <li class="breadcrumb-item">
    <a href="{{route('home')}}">Home</a>
  </li>
  <li class="breadcrumb-item">
    <a href="{{route('sliders.admin.slider.index')}}">Slider</a>
  </li>
  <li class="breadcrumb-item">
    <a href="{{route('sliders.admin.slider.edit', $slider->id)}}">{{$slider->name}}</a>
  </li>
  <li class="breadcrumb-item active">
    Carousel
  </li>
@endsection
@section('content')

<input type="hidden" value="{{ csrf_token() }}" id="_token"/>
<div class='row'>
  <div class='col-md-12'>
    <div class='box'>
      <div class='box-header dark'>
        <h2>
          Imágenes del slider
          <span>
            <a class='btn btn-xs btn-info button-ml' href="{{route('sliders.admin.carousel.create', $slider->id)}}">
              <i class='fas fa-plus'></i>
              Agregar imagen
            </a>
          </span>
        </h2>
      </div>
      <div class='box-body'>
        <div class='col-md-12'>
          <table class='table'>
            <tr>
              <th width="10%" class="text-center">#</th>
              <th width="20%" class="text-center">Título</th>
              <th width="25%" class="text-center">Subtítulo</th>
              <th width="25%" class="text-center">Imagen</th>
              <th width="20%" class="text-center"></th>
            </tr>
            <tbody class="sortable" data-update-url="{{route('sliders.admin.slider.sort', $slider->id)}}"> 
              @if ($banners->count() > 0)    
                @foreach($banners->orderBy("position")->get() as $banner)
                  <tr id="id_banner_{{$banner->id}}">
                    <td>
                      <a class="btn btn-default handle-sort" type="button">
                        <i class="fas fa-arrows-alt"></i> Mover
                      </a>
                    </td>
                    <td>{{$banner->title}}</td>
                    <td>{{$banner->subtitle}}</td>
                    <td class="text-center">
                      @if($banner->image_path != null)
                        <img src="{{asset('storage/'.$banner->image_path)}}" width="100%">
                      @else
                        No imagen
                      @endif
                    </td>
                    <td class="text-center">
                      {!! Form::open(['route'=> ['sliders.admin.carousel.destroy',$slider->id, $banner->id],'method'=>'DELETE'])!!}
                        <button class='btn btn-danger btn-xs button-mb' onclick="return confirm('¿Estás seguro de eliminar este elemento?');" type='submit'>
                          <i class='fas fa-trash-alt icon-special-size'></i>
                          Eliminar
                        </button>
                      {!! Form::close()!!}
                      {!! Form::open(['route'=> ['sliders.admin.carousel.activate',$slider->id,$banner->id],'method'=>'POST'])!!}
                        <button class='btn btn-info btn-xs button-mb' onclick="return confirm('¿Estás seguro que deseas desactivar este elemento?');" type='submit'>
                          <i class='fas fa-arrow-down icon-special-size'></i>
                          Desactivar
                        </button>
                      {!! Form::close()!!}
                      <a class='btn btn-xs accent' href="{{route('sliders.admin.carousel.edit',[ $slider->id, $banner->id])}}">
                        <i class='fas fa-edit icon-special-size'></i>
                        Editar
                      </a>     
                    </td>
                  </tr>  
                @endforeach
              @else
                <tr>
                  <td colspan="5" class="text-center">No hay banners registrados</td>
                </tr>
              @endif
            </tbody>
          </table>
        </div>
      </div>
      <div class='dker p-a text-right'>
      </div>
    </div>
  </div>
</div>
<div class='row'>
  <div class='col-md-12'>
    <div class='box'>
      <div class='box-header dark'>
        <h2>
          Imágenes del carousel (Desactivadas)
        </h2>
      </div>
      <div class='box-body'>
        <div class='col-md-12'>
          <table class='table'>
            <tr>
              <th width="10%" class="text-center">#</th>
              <th width="20%" class="text-center">Título</th>
              <th width="25%" class="text-center">Subtítulo</th>
              <th width="25%" class="text-center">Imagen</th>
              <th width="20%" class="text-center"></th>
            </tr>
            @if ($banners_desactivated->count() > 0 )
              @foreach($banners_desactivated->get() as $banner)
                <tr>
                  <td>{{$banner->id}}</td>
                  <td>{{$banner->title}}</td>
                  <td>{{$banner->subtitle}}</td>
                  <td class="text-center">
                    @if($banner->image_path != null)
                    <img src="{{asset('storage/'.$banner->image_path)}}" width="100%">
                    @else
                      No imagen
                    @endif
                  </td>
                  <td class="text-center">
                    {!! Form::open(['route'=> ['sliders.admin.carousel.destroy',$slider->id,$banner->id],'method'=>'DELETE'])!!}
                      <button class='btn btn-danger btn-xs button-mb' onclick="return confirm('¿Estás seguro de eliminar este elemento?');" type='submit'>
                        <i class='fas fa-trash-alt icon-special-size'></i>
                        Eliminar
                      </button>
                    {!! Form::close()!!}
                    {!! Form::open(['route'=> ['sliders.admin.carousel.activate',$slider->id,$banner->id],'method'=>'POST'])!!}
                      <button class='btn btn-info btn-xs button-mb' onclick="return confirm('¿Estás seguro que deseas activar este elemento?');" type='submit'>
                        <i class='fas fa-arrow-up icon-special-size'></i>
                        Activar
                      </button>
                    {!! Form::close()!!}
                    <a class='btn btn-xs accent' href="{{route('sliders.admin.carousel.edit', [$slider->id, $banner->id])}}">
                      <i class='fas fa-edit icon-special-size'></i>
                      Editar
                    </a>     
                  </td>
                </tr>  
              @endforeach
            @else
              <tr>
                <td colspan="5" class="text-center">No hay banners desactivados</td>
              </tr>
            @endif
          </table>
        </div>
      </div>
      <div class='dker p-a text-right'>
      </div>
    </div>
  </div>
</div>  
  
@endsection

@section('script_extras')
  <script type="text/javascript">
    $(document).ready(function() {
      var CSRF_TOKEN = $('#_token').val();
      console.log("fhsjkdfhjskd");
      $('.sortable').sortable({
          axis: 'y',
          placeholder: "sortable-placeholder",
          handle: '.handle-sort',
          update: function(){
            var parametros = {"_token" : CSRF_TOKEN, "sort" : $(this).sortable('serialize')}
            var URL = $(this).data('update-url');
            $.ajax({
              data : parametros,
              url : URL,
              method : "POST",
              success : function(response){
                console.log("fdsfsd")
                console.log(response);  
              },
              error : function (error){
                console.log(error);
              },
            });
          }
      });
    });
  </script>
@endsection